import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { DrawerHeading } from '@/shared/DrawerHeading';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { layersSelector, layersVisibilitySelector } from '@/redux/layers/layers.selectors';
import { Switch } from '@/shared/Switch';
import { setLayerVisibility } from '@/redux/layers/layers.slice';

export const LayersDrawer = (): JSX.Element => {
  const layers = useAppSelector(layersSelector);
  const layersVisibility = useAppSelector(layersVisibilitySelector);
  const dispatch = useAppDispatch();

  return (
    <div data-testid="layers-drawer" className="h-full max-h-full">
      <DrawerHeading title="Layers" />
      <div className="flex h-[calc(100%-93px)] max-h-[calc(100%-93px)] flex-col overflow-y-auto px-6">
        {layers.map(layer => (
          <div key={layer.details.id} className="flex items-center justify-between border-b p-4">
            <h1>{layer.details.name}</h1>
            <Switch
              isChecked={layersVisibility[layer.details.layerId]}
              onToggle={value =>
                dispatch(setLayerVisibility({ visible: value, layerId: layer.details.layerId }))
              }
            />
          </div>
        ))}
      </div>
    </div>
  );
};
