import { MapSize } from '@/redux/map/map.types';
import { AppDispatch } from '@/redux/store';
import { Map, MapBrowserEvent } from 'ol';
import { Comment, ModelElement, NewReaction } from '@/types/models';
import { updateLastClick } from '@/redux/map/map.slice';
import { toLonLat } from 'ol/proj';
import { latLngToPoint } from '@/utils/map/latLngToPoint';
import { FeatureLike } from 'ol/Feature';
import { closeDrawer } from '@/redux/drawer/drawer.slice';
import { clearBioEntities } from '@/redux/bioEntity/bioEntity.slice';
import { leftClickHandleAlias } from '@/components/Map/MapViewer/MapViewerVector/listeners/mouseClick/mouseLeftClick/leftClickHandleAlias';
import { handleFeaturesClick } from '@/components/Map/MapViewer/utils/listeners/mapSingleClick/handleFeaturesClick';
import { resetReactionsData } from '@/redux/reactions/reactions.slice';
import { handleDataReset } from '@/components/Map/MapViewer/utils/listeners/mapSingleClick/handleDataReset';
import { FEATURE_TYPE } from '@/constants/features';
import { clickHandleReaction } from '@/components/Map/MapViewer/MapViewerVector/listeners/mouseClick/clickHandleReaction';

/* prettier-ignore */
export const onMapLeftClick =
  (mapSize: MapSize, modelId: number, dispatch: AppDispatch, isResultDrawerOpen: boolean, comments: Comment[], modelElements: Array<ModelElement>, reactions: Array<NewReaction>) =>
    async ({ coordinate, pixel }: Pick<MapBrowserEvent<UIEvent>, 'coordinate' | 'pixel'>, mapInstance: Map): Promise<void> => {
      const [lng, lat] = toLonLat(coordinate);
      const point = latLngToPoint([lat, lng], mapSize);

      dispatch(updateLastClick({ coordinates: point, modelId }));

      let featureAtPixel: FeatureLike | undefined;
      mapInstance.forEachFeatureAtPixel(pixel, (feature, ) => {
        if(feature.get('id') && [...Object.values(FEATURE_TYPE)].includes(feature.get('type'))) {
          featureAtPixel = feature;
          return true;
        }
        return false;
      }, {hitTolerance: 10});

      if(!featureAtPixel) {
        if (isResultDrawerOpen) {
          dispatch(closeDrawer());
        }

        dispatch(resetReactionsData());
        dispatch(clearBioEntities());
        return;
      }

      const { shouldBlockCoordSearch } = handleFeaturesClick([featureAtPixel], dispatch, comments);

      if (shouldBlockCoordSearch) {
        return;
      }

      dispatch(handleDataReset);

      const type = featureAtPixel.get('type');
      const id = featureAtPixel.get('id');
      if(type === FEATURE_TYPE.ALIAS) {
        await leftClickHandleAlias(dispatch)(featureAtPixel, modelId);
      } else if (type === FEATURE_TYPE.REACTION) {
        clickHandleReaction(dispatch)(modelElements, reactions, id,  modelId);
      }
    };
