/* eslint-disable @typescript-eslint/explicit-function-return-type */
import { renderHook } from '@testing-library/react';
import { View } from 'ol';
import { getReduxWrapperWithStore } from '@/utils/testing/getReduxWrapperWithStore';
import { initialMapDataFixture, openedMapsThreeSubmapsFixture } from '@/redux/map/map.fixtures';
import { useOlMapVectorListeners } from '@/components/Map/MapViewer/MapViewerVector/listeners/useOlMapVectorListeners';
import { onMapLeftClick } from '@/components/Map/MapViewer/MapViewerVector/listeners/mouseClick/mouseLeftClick/onMapLeftClick';

jest.mock('./mouseClick/mouseLeftClick/onMapLeftClick', () => ({
  __esModule: true,
  onMapLeftClick: jest.fn(),
}));

jest.mock('use-debounce', () => {
  return {
    useDebounce: () => {},
    useDebouncedCallback: () => {},
  };
});

describe('useOlMapVectorListeners - util', () => {
  const { Wrapper } = getReduxWrapperWithStore({
    map: {
      data: { ...initialMapDataFixture },
      loading: 'succeeded',
      error: { message: '', name: '' },
      openedMaps: openedMapsThreeSubmapsFixture,
    },
  });

  beforeEach(() => {
    jest.clearAllMocks();
  });

  describe('on left click event', () => {
    it('should run onMapLeftClick event', () => {
      const CALLED_ONCE = 1;
      const view = new View();

      renderHook(() => useOlMapVectorListeners({ mapInstance: undefined }), {
        wrapper: Wrapper,
      });
      view.dispatchEvent('singleclick');

      expect(onMapLeftClick).toBeCalledTimes(CALLED_ONCE);
    });
  });
});
