/* eslint-disable no-magic-numbers */
import { Feature, Map, View } from 'ol';
import { Style, Icon } from 'ol/style';
import { UsePointToProjectionResult } from '@/utils/map/usePointToProjection';
import Glyph, {
  GlyphProps,
} from '@/components/Map/MapViewer/MapViewerVector/utils/shapes/elements/Glyph';
import { MapInstance } from '@/types/map';
import Polygon from 'ol/geom/Polygon';
import { BASE_NEW_API_URL } from '@/constants';

describe('Glyph', () => {
  let props: GlyphProps;
  let glyph: Glyph;
  let mapInstance: MapInstance;
  let pointToProjectionMock: jest.MockedFunction<UsePointToProjectionResult>;

  beforeEach(() => {
    const dummyElement = document.createElement('div');
    mapInstance = new Map({
      target: dummyElement,
      view: new View({
        zoom: 5,
        minZoom: 3,
        maxZoom: 7,
      }),
    });

    pointToProjectionMock = jest.fn().mockReturnValue([10, 20]);

    props = {
      id: 1,
      x: 10,
      y: 20,
      width: 32,
      height: 32,
      zIndex: 1,
      pointToProjection: pointToProjectionMock,
      mapInstance,
    };
    glyph = new Glyph(props);
  });

  it('should initialize with correct feature and style properties', () => {
    expect(glyph.feature).toBeInstanceOf(Feature);
    const geometry = glyph.feature.getGeometry();
    expect(geometry).toBeInstanceOf(Polygon);
    expect(geometry?.getCoordinates()).toEqual([
      [
        [10, 20],
        [10, 20],
        [10, 20],
        [10, 20],
        [10, 20],
      ],
    ]);

    expect(glyph.style).toBeInstanceOf(Style);
    const image = glyph.style.getImage() as Icon;
    expect(image).toBeInstanceOf(Icon);
    expect(image.getSrc()).toBe(`${BASE_NEW_API_URL}projects/pdmap_appu_test/glyphs/1/fileContent`);
  });

  it('should scale image based on map resolution', () => {
    const getImageScale = glyph.feature.get('getImageScale');
    const getAnchorAndCoords = glyph.feature.get('getAnchorAndCoords');
    if (mapInstance) {
      const resolution = mapInstance
        .getView()
        .getResolutionForZoom(mapInstance.getView().getMaxZoom());
      expect(getImageScale(resolution)).toBe(1);
      expect(getAnchorAndCoords()).toEqual({ anchor: [0, 0], coords: [0, 0] });
    }
  });
});
