import { bioEntityResponseFixture } from '@/models/fixtures/bioEntityContentsFixture';
import { ELEMENT_SEARCH_RESULT_MOCK_ALIAS } from '@/models/mocks/elementSearchResultMock';
import { apiPath } from '@/redux/apiPath';
import { mockNetworkResponse } from '@/utils/mockNetworkResponse';
import { getReduxStoreWithActionsListener } from '@/utils/testing/getReduxStoreActionsListener';
import { HttpStatusCode } from 'axios';
import { waitFor } from '@testing-library/react';
import { FIRST_ARRAY_ELEMENT, SECOND_ARRAY_ELEMENT, SIZE_OF_EMPTY_ARRAY } from '@/constants/common';
import { handleBioEntityResults } from './handleBioEntityResults';

const mockedAxiosOldClient = mockNetworkResponse();

describe('handleBioEntityResults - util', () => {
  const { store } = getReduxStoreWithActionsListener();
  const { dispatch } = store;

  mockedAxiosOldClient
    .onGet(
      apiPath.getBioEntityContentsStringWithQuery({
        searchQuery: ELEMENT_SEARCH_RESULT_MOCK_ALIAS.id.toString(),
        isPerfectMatch: true,
      }),
    )
    .reply(HttpStatusCode.Ok, bioEntityResponseFixture);

  beforeAll(async () => {
    handleBioEntityResults(dispatch)(ELEMENT_SEARCH_RESULT_MOCK_ALIAS);
  });

  it('should run setCurrentSelectedBioEntityId as first action', async () => {
    await waitFor(() => {
      const actions = store.getActions();
      expect(actions.length).toBeGreaterThan(SIZE_OF_EMPTY_ARRAY);
      expect(actions[FIRST_ARRAY_ELEMENT].type).toEqual(
        'contextMenu/setCurrentSelectedBioEntityId',
      );
    });
  });

  it('should run getMultiBioEntity as second action', async () => {
    await waitFor(() => {
      const actions = store.getActions();
      expect(actions.length).toBeGreaterThan(SIZE_OF_EMPTY_ARRAY);
      expect(actions[SECOND_ARRAY_ELEMENT].type).toEqual('project/getMultiBioEntity/pending');
    });
  });
});
