/* eslint-disable no-magic-numbers */
import { newReactionFixture } from '@/models/fixtures/newReactionFixture';
import { ZOOM_RESCALING_FACTOR } from '@/constants/map';
import { findClosestReactionPoint, getReactionLineSegments } from './findClosestReactionPoint';

describe('findClosestReactionPoint', () => {
  const reaction = {
    ...newReactionFixture,
  };

  const validPoint = { x: reaction.line.segments[0].x1, y: reaction.line.segments[0].y1 };

  let x = reaction.line.segments[0].x1;
  let y = reaction.line.segments[0].y1;
  getReactionLineSegments(reaction).forEach(lineSegment => {
    x = Math.min(x, lineSegment.x1);
    x = Math.min(x, lineSegment.x2);
    y = Math.min(y, lineSegment.y1);
    y = Math.min(y, lineSegment.y2);
  });
  const invalidPoint = { x: x - 1000, y: y - 1000 };
  const searchDistance = '10';
  const maxZoom = 10;
  const zoom = ZOOM_RESCALING_FACTOR * 5;

  it('should return the matching line segment if a point within the search distance is found', () => {
    const result = findClosestReactionPoint({
      reaction,
      searchDistance,
      maxZoom,
      zoom,
      point: validPoint,
    });

    expect(result).toEqual(reaction.line.segments[0]);
  });

  it('should return undefined if no point within the search distance is found', () => {
    const result = findClosestReactionPoint({
      reaction,
      searchDistance,
      maxZoom,
      zoom,
      point: invalidPoint,
    });

    expect(result).toBeUndefined();
  });
});
