import { elementSearchResultFixture } from '@/models/fixtures/elementSearchResultFixture';
import { apiPath } from '@/redux/apiPath';
import { HttpStatusCode } from 'axios';
import { mockNetworkResponse } from '../mockNetworkResponse';
import { getElementsByPoint } from './getElementsByCoordinates';

const mockedAxiosClient = mockNetworkResponse();

describe('getElementsByPoint - utils', () => {
  const point = {
    x: 0,
    y: 0,
  };
  const currentModelId = 1000;

  it('should return data when data response from API is valid', async () => {
    mockedAxiosClient
      .onGet(apiPath.getSingleBioEntityContentsStringWithCoordinates(point, currentModelId))
      .reply(HttpStatusCode.Ok, elementSearchResultFixture);

    const response = await getElementsByPoint({
      point,
      currentModelId,
      shouldConsiderZoomLevel: false,
    });
    expect(response).toEqual(elementSearchResultFixture);
  });

  it('should return undefined when data response from API is not valid ', async () => {
    mockedAxiosClient
      .onGet(apiPath.getSingleBioEntityContentsStringWithCoordinates(point, currentModelId))
      .reply(HttpStatusCode.Ok, { randomProperty: 'randomValue' });

    const response = await getElementsByPoint({
      point,
      currentModelId,
      shouldConsiderZoomLevel: false,
    });
    expect(response).toEqual(undefined);
  });

  it('should return empty array when data response from API is empty', async () => {
    mockedAxiosClient
      .onGet(apiPath.getSingleBioEntityContentsStringWithCoordinates(point, currentModelId))
      .reply(HttpStatusCode.Ok, []);

    const response = await getElementsByPoint({
      point,
      currentModelId,
      shouldConsiderZoomLevel: false,
    });
    expect(response).toEqual([]);
  });
});
